@@ -7,8 +7,11 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"sort"
 	"time"
 
+	awsecs "github.com/aws/copilot-cli/internal/pkg/aws/ecs"
+
 	"github.com/aws/aws-sdk-go/service/ssm"
 	"github.com/aws/copilot-cli/internal/pkg/aws/identity"
 
@@ -16,6 +19,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/config"
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
+	"github.com/aws/copilot-cli/internal/pkg/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/logging"
 	"github.com/aws/copilot-cli/internal/pkg/term/log"
 	"github.com/aws/copilot-cli/internal/pkg/term/prompt"
@@ -31,6 +35,10 @@ const (
 	cwGetLogEventsLimitMax = 10000
 )
 
+var (
+	noPreviousTasksErr = errors.New("no previously stopped tasks found")
+)
+
 type wkldLogsVars struct {
 	shouldOutputJSON bool
 	follow           bool
@@ -43,6 +51,8 @@ type wkldLogsVars struct {
 	taskIDs          []string
 	since            time.Duration
 	logGroup         string
+	previous         bool
+	containerName    string
 }
 
 type svcLogsOpts struct {
@@ -57,12 +67,14 @@ type wkldLogOpts struct {
 	startTime *int64
 	endTime   *int64
 
-	w           io.Writer
-	configStore store
-	deployStore deployedEnvironmentLister
-	sel         deploySelector
-	logsSvc     logEventsWriter
-	initLogsSvc func() error // Overridden in tests.
+	w                  io.Writer
+	configStore        store
+	sessProvider       sessionProvider
+	deployStore        deployedEnvironmentLister
+	sel                deploySelector
+	logsSvc            logEventsWriter
+	ecs                serviceDescriber
+	initRuntimeClients func() error // Overridden in tests.
 }
 
 func newSvcLogOpts(vars wkldLogsVars) (*svcLogsOpts, error) {
@@ -86,7 +98,7 @@ func newSvcLogOpts(vars wkldLogsVars) (*svcLogsOpts, error) {
 			sel:         selector.NewDeploySelect(prompt.New(), configStore, deployStore),
 		},
 	}
-	opts.initLogsSvc = func() error {
+	opts.initRuntimeClients = func() error {
 		env, err := opts.getTargetEnv()
 		if err != nil {
 			return fmt.Errorf("get environment: %w", err)
@@ -99,6 +111,7 @@ func newSvcLogOpts(vars wkldLogsVars) (*svcLogsOpts, error) {
 		if err != nil {
 			return err
 		}
+		opts.ecs = ecs.New(sess)
 		opts.logsSvc, err = logging.NewWorkloadClient(&logging.NewWorkloadLogsConfig{
 			App:         opts.appName,
 			Env:         opts.envName,
@@ -109,6 +122,7 @@ func newSvcLogOpts(vars wkldLogsVars) (*svcLogsOpts, error) {
 			TaskIDs:     opts.taskIDs,
 			ConfigStore: configStore,
 		})
+
 		if err != nil {
 			return err
 		}
@@ -155,6 +169,12 @@ func (o *svcLogsOpts) Validate() error {
 		return fmt.Errorf("--limit %d is out-of-bounds, value must be between %d and %d", o.limit, cwGetLogEventsLimitMin, cwGetLogEventsLimitMax)
 	}
 
+	if o.previous {
+		if err := o.validatePrevious(); err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
 
@@ -168,7 +188,7 @@ func (o *svcLogsOpts) Ask() error {
 
 // Execute outputs logs of the service.
 func (o *svcLogsOpts) Execute() error {
-	if err := o.initLogsSvc(); err != nil {
+	if err := o.initRuntimeClients(); err != nil {
 		return err
 	}
 	eventsWriter := logging.WriteHumanLogs
@@ -179,13 +199,25 @@ func (o *svcLogsOpts) Execute() error {
 	if o.limit != 0 {
 		limit = aws.Int64(int64(o.limit))
 	}
+	if o.previous {
+		taskID, err := o.latestStoppedTaskID()
+		if err != nil {
+			if errors.Is(err, noPreviousTasksErr) {
+				log.Warningln("no previously stopped tasks found")
+				return nil // return nil as we have no stopped tasks.
+			}
+			return err
+		}
+		o.taskIDs = []string{taskID}
+	}
 	err := o.logsSvc.WriteLogEvents(logging.WriteLogEventsOpts{
-		Follow:    o.follow,
-		Limit:     limit,
-		EndTime:   o.endTime,
-		StartTime: o.startTime,
-		TaskIDs:   o.taskIDs,
-		OnEvents:  eventsWriter,
+		Follow:        o.follow,
+		Limit:         limit,
+		EndTime:       o.endTime,
+		StartTime:     o.startTime,
+		TaskIDs:       o.taskIDs,
+		OnEvents:      eventsWriter,
+		ContainerName: o.containerName,
 	})
 	if err != nil {
 		return fmt.Errorf("write log events for service %s: %w", o.name, err)
@@ -193,6 +225,24 @@ func (o *svcLogsOpts) Execute() error {
 	return nil
 }
 
+func (o *svcLogsOpts) latestStoppedTaskID() (string, error) {
+	svcDesc, err := o.ecs.DescribeService(o.appName, o.envName, o.name)
+	if err != nil {
+		return "", fmt.Errorf("describe service %s: %w", o.name, err)
+	}
+	if len(svcDesc.StoppedTasks) > 0 {
+		sort.Slice(svcDesc.StoppedTasks, func(i, j int) bool {
+			return svcDesc.StoppedTasks[i].StoppingAt.After(aws.TimeValue(svcDesc.StoppedTasks[j].StoppingAt))
+		})
+		taskID, err := awsecs.TaskID(aws.StringValue(svcDesc.StoppedTasks[0].TaskArn))
+		if err != nil {
+			return "", err
+		}
+		return taskID, nil
+	}
+	return "", noPreviousTasksErr
+}
+
 func (o *svcLogsOpts) validateOrAskApp() error {
 	if o.appName != "" {
 		_, err := o.configStore.GetApplication(o.appName)
@@ -229,6 +279,13 @@ func (o *svcLogsOpts) validateAndAskSvcEnvName() error {
 	return nil
 }
 
+func (o *svcLogsOpts) validatePrevious() error {
+	if o.previous && len(o.taskIDs) != 0 {
+		return fmt.Errorf("cannot specify both --%s and --%s", previousFlag, tasksFlag)
+	}
+	return nil
+}
+
 func (o *svcLogsOpts) getTargetEnv() (*config.Environment, error) {
 	if o.targetEnv != nil {
 		return o.targetEnv, nil
@@ -294,5 +351,7 @@ func buildSvcLogsCmd() *cobra.Command {
 	cmd.Flags().IntVar(&vars.limit, limitFlag, 0, limitFlagDescription)
 	cmd.Flags().StringSliceVar(&vars.taskIDs, tasksFlag, nil, tasksLogsFlagDescription)
 	cmd.Flags().StringVar(&vars.logGroup, logGroupFlag, "", logGroupFlagDescription)
+	// cmd.Flags().BoolVarP(&vars.previous, previousFlag, previousFlagShort, false, previousFlagDescription)
+	// cmd.Flags().StringVar(&vars.containerName, containerLogFlag, "", containerLogFlagDescription)
 	return cmd
 }
