@@ -79,6 +79,7 @@ type cfnClient interface {
 	ErrorEvents(stackName string) ([]cloudformation.StackEvent, error)
 	Outputs(stack *cloudformation.Stack) (map[string]string, error)
 	StackResources(name string) ([]*cloudformation.StackResource, error)
+	Metadata(opts cloudformation.MetadataOpts) (string, error)
 
 	// Methods vended by the aws sdk struct.
 	DescribeStackEvents(*sdkcloudformation.DescribeStackEventsInput) (*sdkcloudformation.DescribeStackEventsOutput, error)
@@ -98,9 +99,12 @@ type s3Client interface {
 
 type stackSetClient interface {
 	Create(name, template string, opts ...stackset.CreateOrUpdateOption) error
+	CreateInstances(name string, accounts, regions []string) (string, error)
 	CreateInstancesAndWait(name string, accounts, regions []string) error
+	Update(name, template string, opts ...stackset.CreateOrUpdateOption) (string, error)
 	UpdateAndWait(name, template string, opts ...stackset.CreateOrUpdateOption) error
 	Describe(name string) (stackset.Description, error)
+	DescribeOperation(name, opID string) (stackset.Operation, error)
 	InstanceSummaries(name string, opts ...stackset.InstanceSummariesOption) ([]stackset.InstanceSummary, error)
 	DeleteAllInstances(name string) (string, error)
 	Delete(name string) error
@@ -144,6 +148,9 @@ type CloudFormation struct {
 
 	// cached variables.
 	cachedDeployedStack *cloudformation.StackDescription
+
+	// Overriden in tests.
+	renderStackSet func(input renderStackSetInput) error
 }
 
 // New returns a configured CloudFormation client.
@@ -166,6 +173,7 @@ func New(sess *session.Session, opts ...OptFn) CloudFormation {
 	for _, opt := range opts {
 		opt(&client)
 	}
+	client.renderStackSet = client.renderStackSetImpl
 	return client
 }
 
@@ -519,7 +527,7 @@ func (cf CloudFormation) errOnFailedStack(stackName string) error {
 		return err
 	}
 	status := aws.StringValue(stack.StackStatus)
-	if cloudformation.StackStatus(status).Failure() {
+	if cloudformation.StackStatus(status).IsFailure() {
 		return fmt.Errorf("stack %s did not complete successfully and exited with status %s", stackName, status)
 	}
 	return nil
