@@ -1,5 +1,4 @@
 //go:build integration || localintegration
-// +build integration localintegration
 
 // Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 // SPDX-License-Identifier: Apache-2.0
@@ -11,6 +10,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/aws/copilot-cli/internal/pkg/config"
+
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"gopkg.in/yaml.v3"
 
@@ -21,6 +22,21 @@ import (
 
 // TestGHPipeline_Template ensures that the CloudFormation template generated for a pipeline matches our pre-defined template.
 func TestGHPipeline_Template(t *testing.T) {
+	var build deploy.Build
+	build.Init(nil, "copilot/pipelines/phonetool-pipeline/")
+	var stage deploy.PipelineStage
+	stage.Init(&config.Environment{
+		App:              "phonetool",
+		Name:             "test",
+		Region:           "us-west-2",
+		AccountID:        "1111",
+		ExecutionRoleARN: "arn:aws:iam::1111:role/phonetool-test-CFNExecutionRole",
+		ManagerRoleARN:   "arn:aws:iam::1111:role/phonetool-test-EnvManagerRole",
+	}, &manifest.PipelineStage{
+		Name:             "test",
+		TestCommands:     []string{`echo "test"`},
+		RequiresApproval: true,
+	}, []string{"api", "frontend"})
 	ps := stack.NewPipelineStackConfig(&deploy.CreatePipelineInput{
 		AppName: "phonetool",
 		Name:    "phonetool-pipeline",
@@ -29,19 +45,8 @@ func TestGHPipeline_Template(t *testing.T) {
 			RepositoryURL: "https://github.com/aws/phonetool",
 			Branch:        "mainline",
 		},
-		Build: deploy.PipelineBuildFromManifest(nil),
-		Stages: []deploy.PipelineStage{
-			{
-				AssociatedEnvironment: &deploy.AssociatedEnvironment{
-					Name:      "test",
-					Region:    "us-west-2",
-					AccountID: "1111",
-				},
-				LocalWorkloads:   []string{"api"},
-				RequiresApproval: false,
-				TestCommands:     []string{`echo "test"`},
-			},
-		},
+		Build:  &build,
+		Stages: []deploy.PipelineStage{stage},
 		ArtifactBuckets: []deploy.ArtifactBucket{
 			{
 				BucketName: "fancy-bucket",
