@@ -135,86 +135,27 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 	}
 
 	testCases := map[string]struct {
-		noImportedCerts  bool
 		mockDependencies func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService)
 		wantedTemplate   string
 		wantedError      error
 	}{
-		"unavailable rule priority lambda template": {
-			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(nil, errors.New("some error"))
-				c.parser = m
-			},
-			wantedTemplate: "",
-			wantedError:    fmt.Errorf("read rule priority lambda: some error"),
-		},
-		"unavailable desired count lambda template": {
-			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(nil, errors.New("some error"))
-				c.parser = m
-			},
-			wantedTemplate: "",
-			wantedError:    fmt.Errorf("read desired count lambda: some error"),
-		},
-		"unavailable env controller lambda template": {
-			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(nil, errors.New("some error"))
-				c.parser = m
-			},
-			wantedTemplate: "",
-			wantedError:    fmt.Errorf("read env controller lambda: some error"),
-		},
 		"unexpected addons template parsing error": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
 				addons := mockAddons{tplErr: errors.New("some error")}
-				c.parser = m
 				c.wkld.addons = addons
 			},
 			wantedError: fmt.Errorf("generate addons template for %s: %w", aws.StringValue(testLBWebServiceManifest.Name), errors.New("some error")),
 		},
 		"unexpected addons parameter parsing error": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
 				addons := mockAddons{paramsErr: errors.New("some error")}
-				c.parser = m
 				c.wkld.addons = addons
 			},
 			wantedError: fmt.Errorf("parse addons parameters for %s: %w", aws.StringValue(testLBWebServiceManifest.Name), errors.New("some error")),
 		},
-		"failed if hosted zone is set without imported certs": {
-			noImportedCerts: true,
-			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
-				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}, paramsErr: &addon.ErrAddonsNotFound{}}
-				c.parser = m
-				c.wkld.addons = addons
-			},
-
-			wantedTemplate: "",
-			wantedError:    fmt.Errorf("cannot specify alias hosted zones when env certificates are managed by Copilot"),
-		},
 		"failed parsing svc template": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
 				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
 				m.EXPECT().ParseLoadBalancedWebService(gomock.Any()).Return(nil, errors.New("some error"))
 				addons := mockAddons{
 					tpl: `
@@ -235,40 +176,40 @@ Outputs:
 		"render template without addons": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
 				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("lambda")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().ParseLoadBalancedWebService(template.WorkloadOpts{
-					WorkloadType: manifest.LoadBalancedWebServiceType,
-					HTTPHealthCheck: template.HTTPHealthCheckOpts{
-						HealthCheckPath: "/",
-						GracePeriod:     aws.Int64(60),
-					},
-					UseImportedCerts: true,
-					HostedZoneAliases: template.AliasesForHostedZone{
-						"mockHostedZone": []string{"mockAlias"},
-					},
-					Aliases:             []string{"mockAlias"},
-					HTTPSListener:       true,
-					DeregistrationDelay: aws.Int64(60),
-					HealthCheck:         &overridenContainerHealthCheck,
-					RulePriorityLambda:  "lambda",
-					DesiredCountLambda:  "something",
-					EnvControllerLambda: "something",
-					Network: template.NetworkOpts{
-						AssignPublicIP: template.EnablePublicIP,
-						SubnetsType:    template.PublicSubnetsPlacement,
-					},
-					DeploymentConfiguration: template.DeploymentConfigurationOpts{
-						MinHealthyPercent: 100,
-						MaxPercent:        200,
-					},
-					EntryPoint: []string{"/bin/echo", "hello"},
-					Command:    []string{"world"},
-					ALBEnabled: true,
-				}).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
+				m.EXPECT().ParseLoadBalancedWebService(gomock.Any()).DoAndReturn(func(actual template.WorkloadOpts) (*template.Content, error) {
+					require.Equal(t, template.WorkloadOpts{
+						AppName:      "phonetool",
+						EnvName:      "test",
+						WorkloadName: "frontend",
+						WorkloadType: manifest.LoadBalancedWebServiceType,
+						HTTPHealthCheck: template.HTTPHealthCheckOpts{
+							HealthCheckPath: "/",
+							GracePeriod:     aws.Int64(60),
+						},
+						HostedZoneAliases: template.AliasesForHostedZone{
+							"mockHostedZone": []string{"mockAlias"},
+						},
+						Aliases:             []string{"mockAlias"},
+						HTTPSListener:       true,
+						DeregistrationDelay: aws.Int64(60),
+						HealthCheck:         &overridenContainerHealthCheck,
+						CustomResources:     make(map[string]template.S3ObjectLocation),
+						Network: template.NetworkOpts{
+							AssignPublicIP: template.EnablePublicIP,
+							SubnetsType:    template.PublicSubnetsPlacement,
+						},
+						DeploymentConfiguration: template.DeploymentConfigurationOpts{
+							MinHealthyPercent: 100,
+							MaxPercent:        200,
+						},
+						EntryPoint: []string{"/bin/echo", "hello"},
+						Command:    []string{"world"},
+						ALBEnabled: true,
+					}, actual)
+					return &template.Content{Buffer: bytes.NewBufferString("template")}, nil
+				})
 
-				addons := mockAddons{tplErr: &addon.ErrAddonsNotFound{}, paramsErr: &addon.ErrAddonsNotFound{}}
+				addons := mockAddons{}
 				c.parser = m
 				c.wkld.addons = addons
 			},
@@ -278,45 +219,45 @@ Outputs:
 		"render template with addons": {
 			mockDependencies: func(t *testing.T, ctrl *gomock.Controller, c *LoadBalancedWebService) {
 				m := mocks.NewMockloadBalancedWebSvcReadParser(ctrl)
-				m.EXPECT().Read(albRulePriorityGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("lambda")}, nil)
-				m.EXPECT().Read(desiredCountGeneratorPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().Read(envControllerPath).Return(&template.Content{Buffer: bytes.NewBufferString("something")}, nil)
-				m.EXPECT().ParseLoadBalancedWebService(template.WorkloadOpts{
-					NestedStack: &template.WorkloadNestedStackOpts{
-						StackName:       addon.StackName,
-						VariableOutputs: []string{"Hello"},
-						SecretOutputs:   []string{"MySecretArn"},
-						PolicyOutputs:   []string{"AdditionalResourcesPolicyArn"},
-					},
-					UseImportedCerts: true,
-					HostedZoneAliases: template.AliasesForHostedZone{
-						"mockHostedZone": []string{"mockAlias"},
-					},
-					Aliases:           []string{"mockAlias"},
-					HTTPSListener:     true,
-					AddonsExtraParams: "ServiceName: !GetAtt Service.Name",
-					WorkloadType:      manifest.LoadBalancedWebServiceType,
-					HTTPHealthCheck: template.HTTPHealthCheckOpts{
-						HealthCheckPath: "/",
-						GracePeriod:     aws.Int64(60),
-					},
-					DeregistrationDelay: aws.Int64(60),
-					HealthCheck:         &overridenContainerHealthCheck,
-					RulePriorityLambda:  "lambda",
-					DesiredCountLambda:  "something",
-					EnvControllerLambda: "something",
-					Network: template.NetworkOpts{
-						AssignPublicIP: template.EnablePublicIP,
-						SubnetsType:    template.PublicSubnetsPlacement,
-					},
-					DeploymentConfiguration: template.DeploymentConfigurationOpts{
-						MinHealthyPercent: 100,
-						MaxPercent:        200,
-					},
-					EntryPoint: []string{"/bin/echo", "hello"},
-					Command:    []string{"world"},
-					ALBEnabled: true,
-				}).Return(&template.Content{Buffer: bytes.NewBufferString("template")}, nil)
+				m.EXPECT().ParseLoadBalancedWebService(gomock.Any()).DoAndReturn(func(actual template.WorkloadOpts) (*template.Content, error) {
+					require.Equal(t, template.WorkloadOpts{
+						AppName:      "phonetool",
+						EnvName:      "test",
+						WorkloadName: "frontend",
+						NestedStack: &template.WorkloadNestedStackOpts{
+							StackName:       addon.StackName,
+							VariableOutputs: []string{"Hello"},
+							SecretOutputs:   []string{"MySecretArn"},
+							PolicyOutputs:   []string{"AdditionalResourcesPolicyArn"},
+						},
+						HostedZoneAliases: template.AliasesForHostedZone{
+							"mockHostedZone": []string{"mockAlias"},
+						},
+						Aliases:           []string{"mockAlias"},
+						HTTPSListener:     true,
+						AddonsExtraParams: "ServiceName: !GetAtt Service.Name",
+						WorkloadType:      manifest.LoadBalancedWebServiceType,
+						HTTPHealthCheck: template.HTTPHealthCheckOpts{
+							HealthCheckPath: "/",
+							GracePeriod:     aws.Int64(60),
+						},
+						DeregistrationDelay: aws.Int64(60),
+						HealthCheck:         &overridenContainerHealthCheck,
+						CustomResources:     make(map[string]template.S3ObjectLocation),
+						Network: template.NetworkOpts{
+							AssignPublicIP: template.EnablePublicIP,
+							SubnetsType:    template.PublicSubnetsPlacement,
+						},
+						DeploymentConfiguration: template.DeploymentConfigurationOpts{
+							MinHealthyPercent: 100,
+							MaxPercent:        200,
+						},
+						EntryPoint: []string{"/bin/echo", "hello"},
+						Command:    []string{"world"},
+						ALBEnabled: true,
+					}, actual)
+					return &template.Content{Buffer: bytes.NewBufferString("template")}, nil
+				})
 				addons := mockAddons{
 					tpl: `Resources:
   AdditionalResourcesPolicy:
@@ -374,12 +315,10 @@ Outputs:
 					},
 					taskDefOverrideFunc: mockCloudFormationOverrideFunc,
 				},
-				certImported: !tc.noImportedCerts,
 				httpsEnabled: true,
 				manifest:     testLBWebServiceManifest,
 			}
 			tc.mockDependencies(t, ctrl, conf)
-
 			// WHEN
 			template, err := conf.Template()
 
