@@ -4,6 +4,7 @@
 package stack
 
 import (
+	"errors"
 	"fmt"
 	"testing"
 	"time"
@@ -235,15 +236,58 @@ func Test_convertSidecar(t *testing.T) {
 
 func Test_convertAdvancedCount(t *testing.T) {
 	mockRange := manifest.IntRangeBand("1-10")
+	timeMinute := time.Second * 60
 	perc := manifest.Percentage(70)
-	mockConfig := manifest.ScalingConfigOrPercentage{
-		Value: &perc,
+	mockConfig := manifest.ScalingConfigOrT[manifest.Percentage]{
+		ScalingConfig: manifest.AdvancedScalingConfig[manifest.Percentage]{
+			Value: &perc,
+			Cooldown: manifest.Cooldown{
+				ScaleInCooldown: &timeMinute,
+			},
+		},
 	}
 	testCases := map[string]struct {
 		input       manifest.AdvancedCount
 		expected    *template.AdvancedCount
 		expectedErr error
 	}{
+		"success with generalized cooldown": {
+			input: manifest.AdvancedCount{
+				Range: manifest.Range{
+					Value: &mockRange,
+				},
+				Cooldown: manifest.Cooldown{
+					ScaleInCooldown:  &timeMinute,
+					ScaleOutCooldown: &timeMinute,
+				},
+			},
+			expected: &template.AdvancedCount{
+				Autoscaling: &template.AutoscalingOpts{
+					MinCapacity: aws.Int(1),
+					MaxCapacity: aws.Int(10),
+					CPUCooldown: template.Cooldown{
+						ScaleInCooldown:  aws.Float64(60),
+						ScaleOutCooldown: aws.Float64(60),
+					},
+					MemCooldown: template.Cooldown{
+						ScaleInCooldown:  aws.Float64(60),
+						ScaleOutCooldown: aws.Float64(60),
+					},
+					ReqCooldown: template.Cooldown{
+						ScaleInCooldown:  aws.Float64(60),
+						ScaleOutCooldown: aws.Float64(60),
+					},
+					RespTimeCooldown: template.Cooldown{
+						ScaleInCooldown:  aws.Float64(60),
+						ScaleOutCooldown: aws.Float64(60),
+					},
+					QueueDelayCooldown: template.Cooldown{
+						ScaleInCooldown:  aws.Float64(60),
+						ScaleOutCooldown: aws.Float64(60),
+					},
+				},
+			},
+		},
 		"success with spot count": {
 			input: manifest.AdvancedCount{
 				Spot: aws.Int(1),
@@ -270,6 +314,9 @@ func Test_convertAdvancedCount(t *testing.T) {
 					MinCapacity: aws.Int(1),
 					MaxCapacity: aws.Int(10),
 					CPU:         aws.Float64(70),
+					CPUCooldown: template.Cooldown{
+						ScaleInCooldown: aws.Float64(60),
+					},
 				},
 			},
 		},
@@ -289,6 +336,9 @@ func Test_convertAdvancedCount(t *testing.T) {
 					MinCapacity: aws.Int(2),
 					MaxCapacity: aws.Int(20),
 					CPU:         aws.Float64(70),
+					CPUCooldown: template.Cooldown{
+						ScaleInCooldown: aws.Float64(60),
+					},
 				},
 				Cps: []*template.CapacityProviderStrategy{
 					{
@@ -410,14 +460,19 @@ func Test_convertCapacityProviders(t *testing.T) {
 
 func Test_convertAutoscaling(t *testing.T) {
 	var (
-		mockRange        = manifest.IntRangeBand("1-100")
-		badRange         = manifest.IntRangeBand("badRange")
-		mockRequests     = 1000
-		mockResponseTime = 512 * time.Millisecond
-		perc             = manifest.Percentage(70)
-		timeMinute       = time.Second * 60
-		mockCPU          = manifest.ScalingConfigOrPercentage{
-			ScalingConfig: manifest.AdvancedScalingConfig{
+		respTime     = 512 * time.Millisecond
+		mockRange    = manifest.IntRangeBand("1-100")
+		badRange     = manifest.IntRangeBand("badRange")
+		mockRequests = manifest.ScalingConfigOrT[int]{
+			Value: aws.Int(1000),
+		}
+		mockResponseTime = manifest.ScalingConfigOrT[time.Duration]{
+			Value: &respTime,
+		}
+		perc       = manifest.Percentage(70)
+		timeMinute = time.Second * 60
+		mockCPU    = manifest.ScalingConfigOrT[manifest.Percentage]{
+			ScalingConfig: manifest.AdvancedScalingConfig[manifest.Percentage]{
 				Value: &perc,
 				Cooldown: manifest.Cooldown{
 					ScaleInCooldown:  &timeMinute,
@@ -425,7 +480,7 @@ func Test_convertAutoscaling(t *testing.T) {
 				},
 			},
 		}
-		mockMem = manifest.ScalingConfigOrPercentage{
+		mockMem = manifest.ScalingConfigOrT[manifest.Percentage]{
 			Value: &perc,
 		}
 	)
@@ -454,15 +509,19 @@ func Test_convertAutoscaling(t *testing.T) {
 				},
 				CPU:          mockCPU,
 				Memory:       mockMem,
-				Requests:     aws.Int(mockRequests),
-				ResponseTime: &mockResponseTime,
+				Requests:     mockRequests,
+				ResponseTime: mockResponseTime,
 			},
 
 			wanted: &template.AutoscalingOpts{
-				MaxCapacity:  aws.Int(100),
-				MinCapacity:  aws.Int(1),
-				CPU:          aws.Float64(70),
-				Memory:       aws.Float64(70),
+				MaxCapacity: aws.Int(100),
+				MinCapacity: aws.Int(1),
+				CPU:         aws.Float64(70),
+				Memory:      aws.Float64(70),
+				CPUCooldown: template.Cooldown{
+					ScaleInCooldown:  aws.Float64(60),
+					ScaleOutCooldown: aws.Float64(60),
+				},
 				Requests:     aws.Float64(1000),
 				ResponseTime: aws.Float64(0.512),
 			},
@@ -478,15 +537,19 @@ func Test_convertAutoscaling(t *testing.T) {
 				},
 				CPU:          mockCPU,
 				Memory:       mockMem,
-				Requests:     aws.Int(mockRequests),
-				ResponseTime: &mockResponseTime,
+				Requests:     mockRequests,
+				ResponseTime: mockResponseTime,
 			},
 
 			wanted: &template.AutoscalingOpts{
-				MaxCapacity:  aws.Int(10),
-				MinCapacity:  aws.Int(5),
-				CPU:          aws.Float64(70),
-				Memory:       aws.Float64(70),
+				MaxCapacity: aws.Int(10),
+				MinCapacity: aws.Int(5),
+				CPU:         aws.Float64(70),
+				Memory:      aws.Float64(70),
+				CPUCooldown: template.Cooldown{
+					ScaleInCooldown:  aws.Float64(60),
+					ScaleOutCooldown: aws.Float64(60),
+				},
 				Requests:     aws.Float64(1000),
 				ResponseTime: aws.Float64(0.512),
 			},
@@ -503,11 +566,17 @@ func Test_convertAutoscaling(t *testing.T) {
 				QueueScaling: manifest.QueueScaling{
 					AcceptableLatency: &testAcceptableLatency,
 					AvgProcessingTime: &testAvgProcessingTime,
+					Cooldown: manifest.Cooldown{
+						ScaleInCooldown: &timeMinute,
+					},
 				},
 			},
 			wanted: &template.AutoscalingOpts{
 				MaxCapacity: aws.Int(10),
 				MinCapacity: aws.Int(5),
+				QueueDelayCooldown: template.Cooldown{
+					ScaleInCooldown: aws.Float64(60),
+				},
 				QueueDelay: &template.AutoscalingQueueDelayOpts{
 					AcceptableBacklogPerTask: 2400,
 				},
@@ -1502,3 +1571,42 @@ func Test_convertHTTPVersion(t *testing.T) {
 		})
 	}
 }
+
+func Test_convertCustomResources(t *testing.T) {
+	testCases := map[string]struct {
+		in        map[string]string
+		wanted    map[string]template.S3ObjectLocation
+		wantedErr error
+	}{
+		"returns a wrapped error if a url cannot be parsed": {
+			in: map[string]string{
+				"EnvControllerFunction":       "https://my-bucket.s3.us-west-2.amazonaws.com/puppy.png",
+				"DynamicDesiredCountFunction": "bad",
+			},
+			wantedErr: errors.New(`convert custom resource "DynamicDesiredCountFunction" url: cannot parse S3 URL bad into bucket name and key`),
+		},
+		"transforms custom resources with valid urls": {
+			in: map[string]string{
+				"EnvControllerFunction": "https://my-bucket.s3.us-west-2.amazonaws.com/good/dogs/puppy.png",
+			},
+			wanted: map[string]template.S3ObjectLocation{
+				"EnvControllerFunction": {
+					Bucket: "my-bucket",
+					Key:    "good/dogs/puppy.png",
+				},
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			out, err := convertCustomResources(tc.in)
+			if tc.wantedErr != nil {
+				require.EqualError(t, err, tc.wantedErr.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wanted, out)
+			}
+		})
+	}
+}
