@@ -85,19 +85,19 @@ func (d *LBWebServiceDescriber) URI(envName string) (URI, error) {
 
 	var uri LBWebServiceURI
 	if albEnabled {
-		albDescr := &albDescriber{
-			svc:             d.svc,
-			env:             envName,
-			svcDescriber:    svcDescr,
-			envDescriber:    envDescr,
-			initLBDescriber: d.initLBDescriber,
-			envDNSNameKey:   envOutputPublicLoadBalancerDNSName,
+		uriDescr := &uriDescriber{
+			svc:              d.svc,
+			env:              envName,
+			svcDescriber:     svcDescr,
+			envDescriber:     envDescr,
+			initLBDescriber:  d.initLBDescriber,
+			albCFNOutputName: envOutputPublicLoadBalancerDNSName,
 		}
-		albURI, err := albDescr.uri()
+		publicURI, err := uriDescr.uri()
 		if err != nil {
 			return URI{}, err
 		}
-		uri.albURI = albURI
+		uri.access = publicURI
 	}
 
 	if nlbEnabled {
@@ -166,20 +166,23 @@ func (d *BackendServiceDescriber) URI(envName string) (URI, error) {
 	}
 	for _, res := range resources {
 		if res.LogicalID == svcStackResourceALBTargetGroupLogicalID {
-			albDescr := &albDescriber{
-				svc:             d.svc,
-				env:             envName,
-				svcDescriber:    svcDescr,
-				envDescriber:    envDescr,
-				initLBDescriber: d.initLBDescriber,
-				envDNSNameKey:   envOutputInternalLoadBalancerDNSName,
+			uriDescr := &uriDescriber{
+				svc:              d.svc,
+				env:              envName,
+				svcDescriber:     svcDescr,
+				envDescriber:     envDescr,
+				initLBDescriber:  d.initLBDescriber,
+				albCFNOutputName: envOutputInternalLoadBalancerDNSName,
 			}
-			albURI, err := albDescr.uri()
+			privateURI, err := uriDescr.uri()
 			if err != nil {
 				return URI{}, err
 			}
+			if !privateURI.HTTPS && len(privateURI.DNSNames) > 1 {
+				privateURI = uriDescr.bestEffortRemoveALBDNSName(privateURI)
+			}
 			return URI{
-				URI:        english.OxfordWordSeries(albURI.strings(), "or"),
+				URI:        english.OxfordWordSeries(privateURI.strings(), "or"),
 				AccessType: URIAccessTypeInternal,
 			}, nil
 		}
@@ -211,57 +214,98 @@ func (d *BackendServiceDescriber) URI(envName string) (URI, error) {
 	}, nil
 }
 
-type albDescriber struct {
-	svc             string
-	env             string
-	svcDescriber    ecsDescriber
-	envDescriber    envDescriber
-	initLBDescriber func(string) (lbDescriber, error)
-	envDNSNameKey   string
+type uriDescriber struct {
+	svc              string
+	env              string
+	svcDescriber     ecsDescriber
+	envDescriber     envDescriber
+	initLBDescriber  func(string) (lbDescriber, error)
+	albCFNOutputName string // The DNS name for the public or private ALB.
 }
 
-func (d *albDescriber) uri() (albURI, error) {
-	svcParams, err := d.svcDescriber.Params()
+func (d *uriDescriber) envDNSName(path string) (accessURI, error) {
+	var dnsNames []string
+
+	envOutputs, err := d.envDescriber.Outputs()
 	if err != nil {
-		return albURI{}, fmt.Errorf("get stack parameters for service %s: %w", d.svc, err)
+		return accessURI{}, fmt.Errorf("get stack outputs for environment %s: %w", d.env, err)
 	}
-	path := svcParams[stack.WorkloadRulePathParamKey]
-	if svcParams[stack.WorkloadHTTPSParamKey] != "true" {
-		envOutputs, err := d.envDescriber.Outputs()
-		if err != nil {
-			return albURI{}, fmt.Errorf("get stack outputs for environment %s: %w", d.env, err)
-		}
-		return albURI{
-			DNSNames: []string{envOutputs[d.envDNSNameKey]},
-			Path:     path,
-		}, nil
+	// Backward compatibility concern since envOutputPublicALBAccessible didn't exist before,
+	// and public ALB DNS name previously was always accessible until the introduction of envOutputPublicALBAccessible.
+	if accessible, ok := envOutputs[envOutputPublicALBAccessible]; !ok || accessible == "true" {
+		dnsNames = append(dnsNames, envOutputs[d.albCFNOutputName])
 	}
-	svcResources, err := d.svcDescriber.ServiceStackResources()
-	if err != nil {
-		return albURI{}, fmt.Errorf("get stack resources for service %s: %w", d.svc, err)
+	if cfDNS, ok := envOutputs[envOutputCloudFrontDomainName]; ok {
+		dnsNames = append(dnsNames, cfDNS)
 	}
-	var httpsRuleARN string
-	for _, resource := range svcResources {
-		if resource.LogicalID == svcStackResourceHTTPSListenerRuleLogicalID &&
-			resource.Type == svcStackResourceHTTPSListenerRuleResourceType {
-			httpsRuleARN = resource.PhysicalID
-		}
-	}
-	lbDescr, err := d.initLBDescriber(d.env)
-	if err != nil {
-		return albURI{}, nil
-	}
-	dnsNames, err := lbDescr.ListenerRuleHostHeaders(httpsRuleARN)
-	if err != nil {
-		return albURI{}, fmt.Errorf("get host headers for listener rule %s: %w", httpsRuleARN, err)
-	}
-	return albURI{
-		HTTPS:    true,
+	return accessURI{
 		DNSNames: dnsNames,
 		Path:     path,
 	}, nil
 }
 
+func (d *uriDescriber) uri() (accessURI, error) {
+	svcParams, err := d.svcDescriber.Params()
+	if err != nil {
+		return accessURI{}, fmt.Errorf("get stack parameters for service %s: %w", d.svc, err)
+	}
+
+	path := svcParams[stack.WorkloadRulePathParamKey]
+	httpsEnabled := svcParams[stack.WorkloadHTTPSParamKey] == "true"
+
+	// public load balancers use the env DNS name if https is not enabled
+	if d.albCFNOutputName == envOutputPublicLoadBalancerDNSName && !httpsEnabled {
+		return d.envDNSName(path)
+	}
+
+	svcResources, err := d.svcDescriber.ServiceStackResources()
+	if err != nil {
+		return accessURI{}, fmt.Errorf("get stack resources for service %s: %w", d.svc, err)
+	}
+
+	var ruleARN string
+	for _, resource := range svcResources {
+		if resource.Type == svcStackResourceListenerRuleResourceType &&
+			((httpsEnabled && resource.LogicalID == svcStackResourceHTTPSListenerRuleLogicalID) ||
+				(!httpsEnabled && resource.LogicalID == svcStackResourceHTTPListenerRuleLogicalID)) {
+			ruleARN = resource.PhysicalID
+			break
+		}
+	}
+
+	lbDescr, err := d.initLBDescriber(d.env)
+	if err != nil {
+		return accessURI{}, nil
+	}
+	dnsNames, err := lbDescr.ListenerRuleHostHeaders(ruleARN)
+	if err != nil {
+		return accessURI{}, fmt.Errorf("get host headers for listener rule %s: %w", ruleARN, err)
+	}
+	if len(dnsNames) == 0 {
+		return d.envDNSName(path)
+	}
+	return accessURI{
+		HTTPS:    httpsEnabled,
+		DNSNames: dnsNames,
+		Path:     path,
+	}, nil
+}
+
+func (d *uriDescriber) bestEffortRemoveALBDNSName(accessURI accessURI) accessURI {
+	envOutputs, err := d.envDescriber.Outputs()
+	if err != nil {
+		return accessURI
+	}
+	lbDNSName := envOutputs[d.albCFNOutputName]
+	for i := range accessURI.DNSNames {
+		if accessURI.DNSNames[i] == lbDNSName {
+			accessURI.DNSNames = append(accessURI.DNSNames[:i], accessURI.DNSNames[i+1:]...)
+			break
+		}
+	}
+	return accessURI
+}
+
 // URI returns the WebServiceURI to identify this service uniquely given an environment name.
 func (d *RDWebServiceDescriber) URI(envName string) (URI, error) {
 	describer, err := d.initAppRunnerDescriber(envName)
@@ -282,13 +326,13 @@ func (d *RDWebServiceDescriber) URI(envName string) (URI, error) {
 
 // LBWebServiceURI represents the unique identifier to access a load balanced web service.
 type LBWebServiceURI struct {
-	albURI albURI
+	access accessURI
 	nlbURI nlbURI
 }
 
-type albURI struct {
+type accessURI struct {
 	HTTPS    bool
-	DNSNames []string // The environment's subdomain if the service is served on HTTPS. Otherwise, the public application load balancer's DNS.
+	DNSNames []string // The environment's subdomain if the service is served on HTTPS. Otherwise, the public application load balancer's access point.
 	Path     string   // Empty if the service is served on HTTPS. Otherwise, the pattern used to match the service.
 }
 
@@ -298,14 +342,14 @@ type nlbURI struct {
 }
 
 func (u *LBWebServiceURI) String() string {
-	uris := u.albURI.strings()
+	uris := u.access.strings()
 	for _, dnsName := range u.nlbURI.DNSNames {
 		uris = append(uris, fmt.Sprintf("%s:%s", dnsName, u.nlbURI.Port))
 	}
 	return english.OxfordWordSeries(uris, "or")
 }
 
-func (u *albURI) strings() []string {
+func (u *accessURI) strings() []string {
 	var uris []string
 	for _, dnsName := range u.DNSNames {
 		protocol := "http://"
