@@ -23,10 +23,6 @@ func (r *RoutingRuleConfigOrBool) Disabled() bool {
 	return r.Enabled != nil && !aws.BoolValue(r.Enabled)
 }
 
-func (r *RoutingRuleConfigOrBool) isEmpty() bool {
-	return r.Enabled == nil && r.RoutingRuleConfiguration.IsEmpty()
-}
-
 // UnmarshalYAML implements the yaml(v3) interface. It allows https routing rule to be specified as a
 // bool or a struct alternately.
 func (r *RoutingRuleConfigOrBool) UnmarshalYAML(value *yaml.Node) error {
@@ -99,15 +95,22 @@ type AdvancedAlias struct {
 	HostedZone *string `yaml:"hosted_zone"`
 }
 
-func (a *AdvancedAlias) isEmpty() bool {
-	return a.Alias == nil && a.HostedZone == nil
-}
-
 // Alias is a custom type which supports unmarshaling "http.alias" yaml which
-// can either be of type advancedAlias slice or type stringSliceOrString.
+// can either be of type advancedAlias slice or type StringSliceOrString.
 type Alias struct {
 	AdvancedAliases     []AdvancedAlias
-	StringSliceOrString stringSliceOrString
+	StringSliceOrString StringSliceOrString
+}
+
+// HostedZones returns all the hosted zones.
+func (a *Alias) HostedZones() []string {
+	var hostedZones []string
+	for _, alias := range a.AdvancedAliases {
+		if alias.HostedZone != nil {
+			hostedZones = append(hostedZones, *alias.HostedZone)
+		}
+	}
+	return hostedZones
 }
 
 // IsEmpty returns empty if Alias is empty.
@@ -130,10 +133,10 @@ func (a *Alias) UnmarshalYAML(value *yaml.Node) error {
 
 	if len(a.AdvancedAliases) != 0 {
 		// Unmarshaled successfully to s.StringSlice, unset s.String, and return.
-		a.StringSliceOrString = stringSliceOrString{}
+		a.StringSliceOrString = StringSliceOrString{}
 		return nil
 	}
-	if err := unmarshalYAMLToStringSliceOrString(&a.StringSliceOrString, value); err != nil {
+	if err := a.StringSliceOrString.UnmarshalYAML(value); err != nil {
 		return errUnmarshalAlias
 	}
 	return nil
@@ -141,16 +144,12 @@ func (a *Alias) UnmarshalYAML(value *yaml.Node) error {
 
 // ToStringSlice converts an Alias to a slice of string.
 func (a *Alias) ToStringSlice() ([]string, error) {
-	if len(a.AdvancedAliases) != 0 {
-		aliases := make([]string, len(a.AdvancedAliases))
-		for i, advancedAlias := range a.AdvancedAliases {
-			aliases[i] = aws.StringValue(advancedAlias.Alias)
-		}
-		return aliases, nil
+	if len(a.AdvancedAliases) == 0 {
+		return a.StringSliceOrString.toStringSlice(), nil
 	}
-	aliases, err := toStringSlice(&a.StringSliceOrString)
-	if err != nil {
-		return nil, err
+	aliases := make([]string, len(a.AdvancedAliases))
+	for i, advancedAlias := range a.AdvancedAliases {
+		aliases[i] = aws.StringValue(advancedAlias.Alias)
 	}
 	return aliases, nil
 }
