@@ -296,7 +296,7 @@ func TestAliasTransformer_Transformer(t *testing.T) {
 				}
 			},
 			override: func(a *Alias) {
-				a.StringSliceOrString = stringSliceOrString{
+				a.StringSliceOrString = StringSliceOrString{
 					StringSlice: []string{"mock", "string", "slice"},
 				}
 			},
@@ -306,7 +306,7 @@ func TestAliasTransformer_Transformer(t *testing.T) {
 		},
 		"StringSliceOrString set to empty if advanced alias is not nil": {
 			original: func(a *Alias) {
-				a.StringSliceOrString = stringSliceOrString{
+				a.StringSliceOrString = StringSliceOrString{
 					StringSlice: []string{"mock", "string", "slice"},
 				}
 			},
@@ -351,29 +351,29 @@ func TestAliasTransformer_Transformer(t *testing.T) {
 
 func TestStringSliceOrStringTransformer_Transformer(t *testing.T) {
 	testCases := map[string]struct {
-		original func(s *stringSliceOrString)
-		override func(s *stringSliceOrString)
-		wanted   func(s *stringSliceOrString)
+		original func(s *StringSliceOrString)
+		override func(s *StringSliceOrString)
+		wanted   func(s *StringSliceOrString)
 	}{
 		"string set to empty if string slice is not nil": {
-			original: func(s *stringSliceOrString) {
+			original: func(s *StringSliceOrString) {
 				s.String = aws.String("mockString")
 			},
-			override: func(s *stringSliceOrString) {
+			override: func(s *StringSliceOrString) {
 				s.StringSlice = []string{"mock", "string", "slice"}
 			},
-			wanted: func(s *stringSliceOrString) {
+			wanted: func(s *StringSliceOrString) {
 				s.StringSlice = []string{"mock", "string", "slice"}
 			},
 		},
 		"string slice set to empty if string is not nil": {
-			original: func(s *stringSliceOrString) {
+			original: func(s *StringSliceOrString) {
 				s.StringSlice = []string{"mock", "string", "slice"}
 			},
-			override: func(s *stringSliceOrString) {
+			override: func(s *StringSliceOrString) {
 				s.String = aws.String("mockString")
 			},
-			wanted: func(s *stringSliceOrString) {
+			wanted: func(s *StringSliceOrString) {
 				s.String = aws.String("mockString")
 			},
 		},
@@ -381,7 +381,7 @@ func TestStringSliceOrStringTransformer_Transformer(t *testing.T) {
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			var dst, override, wanted stringSliceOrString
+			var dst, override, wanted StringSliceOrString
 
 			tc.original(&dst)
 			tc.override(&override)
@@ -476,19 +476,25 @@ func TestPlacementArgsOrStringTransformer_Transformer(t *testing.T) {
 			},
 			override: func(p *PlacementArgOrString) {
 				p.PlacementArgs = PlacementArgs{
-					Subnets: []string{"id1"},
+					Subnets: SubnetListOrArgs{
+						IDs: []string{"id1"},
+					},
 				}
 			},
 			wanted: func(p *PlacementArgOrString) {
 				p.PlacementArgs = PlacementArgs{
-					Subnets: []string{"id1"},
+					Subnets: SubnetListOrArgs{
+						IDs: []string{"id1"},
+					},
 				}
 			},
 		},
 		"args set to empty if string is not nil": {
 			original: func(p *PlacementArgOrString) {
 				p.PlacementArgs = PlacementArgs{
-					Subnets: []string{"id1"},
+					Subnets: SubnetListOrArgs{
+						IDs: []string{"id1"},
+					},
 				}
 			},
 			override: func(p *PlacementArgOrString) {
@@ -522,6 +528,70 @@ func TestPlacementArgsOrStringTransformer_Transformer(t *testing.T) {
 	}
 }
 
+func TestSubnetListOrArgsTransformer_Transformer(t *testing.T) {
+	mockSubnetIDs := []string{"id1", "id2"}
+	mockSubnetFromTags := map[string]StringSliceOrString{
+		"foo": {
+			String: aws.String("bar"),
+		},
+	}
+	testCases := map[string]struct {
+		original func(p *SubnetListOrArgs)
+		override func(p *SubnetListOrArgs)
+		wanted   func(p *SubnetListOrArgs)
+	}{
+		"string slice set to empty if args is not nil": {
+			original: func(s *SubnetListOrArgs) {
+				s.IDs = mockSubnetIDs
+			},
+			override: func(s *SubnetListOrArgs) {
+				s.SubnetArgs = SubnetArgs{
+					FromTags: mockSubnetFromTags,
+				}
+			},
+			wanted: func(s *SubnetListOrArgs) {
+				s.SubnetArgs = SubnetArgs{
+					FromTags: mockSubnetFromTags,
+				}
+			},
+		},
+		"args set to empty if string is not nil": {
+			original: func(s *SubnetListOrArgs) {
+				s.SubnetArgs = SubnetArgs{
+					FromTags: mockSubnetFromTags,
+				}
+			},
+			override: func(s *SubnetListOrArgs) {
+				s.IDs = mockSubnetIDs
+			},
+			wanted: func(s *SubnetListOrArgs) {
+				s.IDs = mockSubnetIDs
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			var dst, override, wanted SubnetListOrArgs
+
+			tc.original(&dst)
+			tc.override(&override)
+			tc.wanted(&wanted)
+
+			// Perform default merge.
+			err := mergo.Merge(&dst, override, mergo.WithOverride)
+			require.NoError(t, err)
+
+			// Use custom transformer.
+			err = mergo.Merge(&dst, override, mergo.WithOverride, mergo.WithTransformers(subnetListOrArgsTransformer{}))
+			require.NoError(t, err)
+
+			require.NoError(t, err)
+			require.Equal(t, wanted, dst)
+		})
+	}
+}
+
 func TestHealthCheckArgsOrStringTransformer_Transformer(t *testing.T) {
 	testCases := map[string]struct {
 		original func(h *HealthCheckArgsOrString)
@@ -643,9 +713,12 @@ func TestCountTransformer_Transformer(t *testing.T) {
 
 func TestAdvancedCountTransformer_Transformer(t *testing.T) {
 	perc := Percentage(80)
-	mockConfig := ScalingConfigOrPercentage{
+	mockConfig := ScalingConfigOrT[Percentage]{
 		Value: &perc,
 	}
+	mockReq := ScalingConfigOrT[int]{
+		Value: aws.Int(42),
+	}
 	testCases := map[string]struct {
 		original func(a *AdvancedCount)
 		override func(a *AdvancedCount)
@@ -660,14 +733,14 @@ func TestAdvancedCountTransformer_Transformer(t *testing.T) {
 					Value: (*IntRangeBand)(aws.String("1-10")),
 				}
 				a.CPU = mockConfig
-				a.Requests = aws.Int(42)
+				a.Requests = mockReq
 			},
 			wanted: func(a *AdvancedCount) {
 				a.Range = Range{
 					Value: (*IntRangeBand)(aws.String("1-10")),
 				}
 				a.CPU = mockConfig
-				a.Requests = aws.Int(42)
+				a.Requests = mockReq
 			},
 		},
 		"auto scaling set to empty if spot is not nil": {
@@ -676,7 +749,7 @@ func TestAdvancedCountTransformer_Transformer(t *testing.T) {
 					Value: (*IntRangeBand)(aws.String("1-10")),
 				}
 				a.CPU = mockConfig
-				a.Requests = aws.Int(42)
+				a.Requests = mockReq
 			},
 			override: func(a *AdvancedCount) {
 				a.Spot = aws.Int(24)
@@ -709,35 +782,35 @@ func TestAdvancedCountTransformer_Transformer(t *testing.T) {
 	}
 }
 
-func TestScalingConfigOrPercentage_Transformer(t *testing.T) {
+func TestScalingConfigOrT_Transformer(t *testing.T) {
 	perc := Percentage(80)
-	mockConfig := AdvancedScalingConfig{
+	mockConfig := AdvancedScalingConfig[Percentage]{
 		Value: &perc,
 	}
 	testCases := map[string]struct {
-		original func(s *ScalingConfigOrPercentage)
-		override func(s *ScalingConfigOrPercentage)
-		wanted   func(s *ScalingConfigOrPercentage)
+		original func(s *ScalingConfigOrT[Percentage])
+		override func(s *ScalingConfigOrT[Percentage])
+		wanted   func(s *ScalingConfigOrT[Percentage])
 	}{
 		"advanced config value set to nil if percentage is not nil": {
-			original: func(s *ScalingConfigOrPercentage) {
+			original: func(s *ScalingConfigOrT[Percentage]) {
 				s.ScalingConfig = mockConfig
 			},
-			override: func(s *ScalingConfigOrPercentage) {
+			override: func(s *ScalingConfigOrT[Percentage]) {
 				s.Value = &perc
 			},
-			wanted: func(s *ScalingConfigOrPercentage) {
+			wanted: func(s *ScalingConfigOrT[Percentage]) {
 				s.Value = &perc
 			},
 		},
 		"percentage set to nil if advanced config value is not nil": {
-			original: func(s *ScalingConfigOrPercentage) {
+			original: func(s *ScalingConfigOrT[Percentage]) {
 				s.Value = &perc
 			},
-			override: func(s *ScalingConfigOrPercentage) {
+			override: func(s *ScalingConfigOrT[Percentage]) {
 				s.ScalingConfig = mockConfig
 			},
-			wanted: func(s *ScalingConfigOrPercentage) {
+			wanted: func(s *ScalingConfigOrT[Percentage]) {
 				s.ScalingConfig = mockConfig
 			},
 		},
@@ -745,7 +818,7 @@ func TestScalingConfigOrPercentage_Transformer(t *testing.T) {
 
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			var dst, override, wanted ScalingConfigOrPercentage
+			var dst, override, wanted ScalingConfigOrT[Percentage]
 
 			tc.original(&dst)
 			tc.override(&override)
@@ -756,7 +829,7 @@ func TestScalingConfigOrPercentage_Transformer(t *testing.T) {
 			require.NoError(t, err)
 
 			// Use custom transformer.
-			err = mergo.Merge(&dst, override, mergo.WithOverride, mergo.WithTransformers(scalingConfigOrPercentageTransformer{}))
+			err = mergo.Merge(&dst, override, mergo.WithOverride, mergo.WithTransformers(scalingConfigOrTTransformer[Percentage]{}))
 			require.NoError(t, err)
 
 			require.NoError(t, err)
@@ -1121,3 +1194,61 @@ func TestSecretTransformer_Transformer(t *testing.T) {
 		})
 	}
 }
+
+func TestEnvironmentCDNConfigTransformer_Transformer(t *testing.T) {
+	testCases := map[string]struct {
+		original func(cfg *environmentCDNConfig)
+		override func(cfg *environmentCDNConfig)
+		wanted   func(cfg *environmentCDNConfig)
+	}{
+		"cdnconfig set to empty if enabled is not nil": {
+			original: func(cfg *environmentCDNConfig) {
+				cfg.Config = advancedCDNConfig{
+					Certificate: aws.String("arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"),
+				}
+			},
+			override: func(cfg *environmentCDNConfig) {
+				cfg.Enabled = aws.Bool(true)
+			},
+			wanted: func(cfg *environmentCDNConfig) {
+				cfg.Enabled = aws.Bool(true)
+			},
+		},
+		"enabled set to nil if cdnconfig is not empty": {
+			original: func(cfg *environmentCDNConfig) {
+				cfg.Enabled = aws.Bool(true)
+			},
+			override: func(cfg *environmentCDNConfig) {
+				cfg.Config = advancedCDNConfig{
+					Certificate: aws.String("arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"),
+				}
+			},
+			wanted: func(cfg *environmentCDNConfig) {
+				cfg.Config = advancedCDNConfig{
+					Certificate: aws.String("arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"),
+				}
+			},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			var dst, override, wanted environmentCDNConfig
+
+			tc.original(&dst)
+			tc.override(&override)
+			tc.wanted(&wanted)
+
+			// Perform default merge.
+			err := mergo.Merge(&dst, override, mergo.WithOverride)
+			require.NoError(t, err)
+
+			// Use custom transformer.
+			err = mergo.Merge(&dst, override, mergo.WithOverride, mergo.WithTransformers(environmentCDNConfigTransformer{}))
+			require.NoError(t, err)
+
+			require.NoError(t, err)
+			require.Equal(t, wanted, dst)
+		})
+	}
+}
