@@ -5,6 +5,7 @@ package manifest
 
 import (
 	"errors"
+	"fmt"
 	"testing"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -45,7 +46,7 @@ func TestEnvironment_Validate(t *testing.T) {
 	}
 }
 
-func TestEnvironmentConfig_Validate(t *testing.T) {
+func TestEnvironmentConfig_validate(t *testing.T) {
 	mockPublicSubnet1CIDR := IPNet("10.0.0.0/24")
 	mockPublicSubnet2CIDR := IPNet("10.0.1.0/24")
 	mockPrivateSubnet1CIDR := IPNet("10.0.3.0/24")
@@ -84,7 +85,7 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 					},
 				},
 
-				HTTPConfig: environmentHTTPConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
 					Private: privateHTTPConfig{
 						InternalALBSubnets: []string{"mockSubnet"},
 					},
@@ -92,6 +93,150 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 			},
 			wantedError: "in order to specify internal ALB subnet placement, subnets must be imported",
 		},
+		"error if invalid security group config": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						SecurityGroupConfig: securityGroupConfig{
+							Ingress: []securityGroupRule{
+								{
+									IpProtocol: "tcp",
+									Ports: portsConfig{
+										Port: aws.Int(80),
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+			wantedError: "validate \"security_group\": validate ingress[0]: \"cidr\" must be specified",
+		},
+		"valid security group config": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						SecurityGroupConfig: securityGroupConfig{
+							Ingress: []securityGroupRule{
+								{
+									CidrIP:     "0.0.0.0",
+									IpProtocol: "tcp",
+									Ports: portsConfig{
+										Range: (*IntRangeBand)(aws.String("1-10")),
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+		},
+		"invalid ports value in security group config": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						SecurityGroupConfig: securityGroupConfig{
+							Ingress: []securityGroupRule{
+								{
+									CidrIP:     "0.0.0.0",
+									IpProtocol: "tcp",
+									Ports: portsConfig{
+										Range: (*IntRangeBand)(aws.String("1-10-10")),
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+			wantedError: "validate \"security_group\": validate ingress[0]: invalid range value 1-10-10: valid format is ${from_port}-${to_port}",
+		},
+		"valid security group config without ports": {
+			in: EnvironmentConfig{
+				Network: environmentNetworkConfig{
+					VPC: environmentVPCConfig{
+						SecurityGroupConfig: securityGroupConfig{
+							Ingress: []securityGroupRule{
+								{
+									CidrIP:     "0.0.0.0",
+									IpProtocol: "tcp",
+								},
+							},
+						},
+					},
+				},
+			},
+			wantedError: "validate \"security_group\": validate ingress[0]: \"ports\" must be specified",
+		},
+		"error if security group ingress is limited to a cdn distribution not enabled": {
+			in: EnvironmentConfig{
+				CDNConfig: environmentCDNConfig{
+					Enabled: aws.Bool(false),
+				},
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						SecurityGroupConfig: ALBSecurityGroupsConfig{
+							Ingress: Ingress{
+								RestrictiveIngress: RestrictiveIngress{
+									CDNIngress: aws.Bool(true),
+								},
+							},
+						},
+					},
+				},
+			},
+			wantedError: "CDN must be enabled to limit security group ingress to CloudFront",
+		},
+		"valid elb access logs config with bucket_prefix": {
+			in: EnvironmentConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						ELBAccessLogs: ELBAccessLogsArgsOrBool{
+							AdvancedConfig: ELBAccessLogsArgs{
+								Prefix: aws.String("prefix"),
+							},
+						},
+					},
+				},
+			},
+		},
+		"valid elb access logs config with both bucket_prefix and bucket_name": {
+			in: EnvironmentConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						ELBAccessLogs: ELBAccessLogsArgsOrBool{
+							AdvancedConfig: ELBAccessLogsArgs{
+								Prefix:     aws.String("prefix"),
+								BucketName: aws.String("bucketName"),
+							},
+						},
+					},
+				},
+			},
+		},
+		"error if cdn cert specified but public certs not specified": {
+			in: EnvironmentConfig{
+				CDNConfig: environmentCDNConfig{
+					Config: advancedCDNConfig{
+						Certificate: aws.String("arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"),
+					},
+				},
+			},
+			wantedError: "\"http.public.certificates\" must be specified if \"cdn.certificate\" is specified",
+		},
+		"error if cdn cert not specified but public certs imported": {
+			in: EnvironmentConfig{
+				CDNConfig: environmentCDNConfig{
+					Enabled: aws.Bool(true),
+				},
+				HTTPConfig: EnvironmentHTTPConfig{
+					Public: PublicHTTPConfig{
+						Certificates: []string{"arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"},
+					},
+				},
+			},
+			wantedError: "\"cdn.certificate\" must be specified if \"http.public.certificates\" and \"cdn\" are specified",
+		},
 		"error if subnets specified for internal ALB placement don't exist": {
 			in: EnvironmentConfig{
 				Network: environmentNetworkConfig{
@@ -105,7 +250,7 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 						},
 					},
 				},
-				HTTPConfig: environmentHTTPConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
 					Private: privateHTTPConfig{
 						InternalALBSubnets: []string{"nonexistentSubnet"},
 					},
@@ -130,7 +275,7 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 						},
 					},
 				},
-				HTTPConfig: environmentHTTPConfig{
+				HTTPConfig: EnvironmentHTTPConfig{
 					Private: privateHTTPConfig{
 						InternalALBSubnets: []string{"existentSubnet", "anotherExistentSubnet"},
 					},
@@ -140,7 +285,7 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedError != "" {
 				require.Error(t, gotErr)
 				require.Contains(t, gotErr.Error(), tc.wantedError)
@@ -151,7 +296,7 @@ func TestEnvironmentConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestEnvironmentNetworkConfig_Validate(t *testing.T) {
+func TestEnvironmentNetworkConfig_validate(t *testing.T) {
 	mockVPCCIDR := IPNet("10.0.0.0/16")
 	testCases := map[string]struct {
 		in                   environmentNetworkConfig
@@ -170,7 +315,7 @@ func TestEnvironmentNetworkConfig_Validate(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedErrorMsgPrefix != "" {
 				require.Error(t, gotErr)
 				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
@@ -181,7 +326,7 @@ func TestEnvironmentNetworkConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestEnvironmentVPCConfig_Validate(t *testing.T) {
+func TestEnvironmentVPCConfig_validate(t *testing.T) {
 	var (
 		mockVPCCIDR            = IPNet("10.0.0.0/16")
 		mockPublicSubnet1CIDR  = IPNet("10.0.0.0/24")
@@ -232,14 +377,14 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": public[0] must include "id" field if the vpc is imported`),
+			wantedErr: errors.New(`validate "subnets" for an imported VPC: validate public[0]: "id" must be specified`),
 		},
 		"error if importing vpc while no subnet is imported": {
 			in: environmentVPCConfig{
 				ID:      aws.String("vpc-1234"),
 				Subnets: subnetsConfiguration{},
 			},
-			wantedErr: errors.New(`validate "subnets": VPC must have subnets in order to proceed with environment creation`),
+			wantedErr: errors.New(`validate "subnets" for an imported VPC: VPC must have subnets in order to proceed with environment creation`),
 		},
 		"error if importing vpc while only one private subnet is imported": {
 			in: environmentVPCConfig{
@@ -260,7 +405,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": validate "public": at least two public subnets must be imported to enable Load Balancing`),
+			wantedErr: errors.New(`validate "subnets" for an imported VPC: validate "public": at least two public subnets must be imported to enable Load Balancing`),
 		},
 		"error if importing vpc while only one public subnet is imported": {
 			in: environmentVPCConfig{
@@ -281,7 +426,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": validate "private": at least two private subnets must be imported`),
+			wantedErr: errors.New(`validate "subnets" for an imported VPC: validate "private": at least two private subnets must be imported`),
 		},
 		"error if configuring vpc without enough azs": {
 			in: environmentVPCConfig{
@@ -309,7 +454,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": require at least 2 availability zones`),
+			wantedErr: errors.New(`validate "subnets" for an adjusted VPC: require at least 2 availability zones`),
 		},
 		"error if configuring vpc while some subnets are imported": {
 			in: environmentVPCConfig{
@@ -326,7 +471,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": public[1] must include "cidr" and "az" fields if the vpc is configured`),
+			wantedErr: errors.New(`validate "subnets" for an adjusted VPC: validate public[1]: "cidr" must be specified`),
 		},
 		"error if configuring vpc while azs do not match between private and public subnets": {
 			in: environmentVPCConfig{
@@ -354,7 +499,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New("validate \"subnets\": public subnets and private subnets do not span the same availability zones"),
+			wantedErr: errors.New("validate \"subnets\" for an adjusted VPC: public subnets and private subnets do not span the same availability zones"),
 		},
 		"error if configuring vpc while the number of public subnet CIDR does not match the number of azs": {
 			in: environmentVPCConfig{
@@ -386,7 +531,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": validate "public": number of public subnet CIDRs (3) does not match number of AZs (2)`),
+			wantedErr: errors.New(`validate "subnets" for an adjusted VPC: validate "public": number of public subnet CIDRs (3) does not match number of AZs (2)`),
 		},
 		"error if configuring vpc while the number of private subnet CIDR does not match the number of azs": {
 			in: environmentVPCConfig{
@@ -418,7 +563,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 					},
 				},
 			},
-			wantedErr: errors.New(`validate "subnets": validate "private": number of private subnet CIDRs (3) does not match number of AZs (2)`),
+			wantedErr: errors.New(`validate "subnets" for an adjusted VPC: validate "private": number of private subnet CIDRs (3) does not match number of AZs (2)`),
 		},
 		"succeed on imported vpc": {
 			in: environmentVPCConfig{
@@ -443,7 +588,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 				},
 			},
 		},
-		"succeed on managed vpc": {
+		"succeed on managed vpc that is fully adjusted ": {
 			in: environmentVPCConfig{
 				CIDR: &mockVPCCIDR,
 				Subnets: subnetsConfiguration{
@@ -478,11 +623,40 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 				},
 			},
 		},
+		"succeed on managed vpc that does not adjust az": {
+			in: environmentVPCConfig{
+				CIDR: &mockVPCCIDR,
+				Subnets: subnetsConfiguration{
+					Public: []subnetConfiguration{
+						{
+							CIDR: &mockPublicSubnet1CIDR,
+						},
+						{
+							CIDR: &mockPublicSubnet2CIDR,
+						},
+						{
+							CIDR: &mockPublicSubnet3CIDR,
+						},
+					},
+					Private: []subnetConfiguration{
+						{
+							CIDR: &mockPrivateSubnet1CIDR,
+						},
+						{
+							CIDR: &mockPrivateSubnet2CIDR,
+						},
+						{
+							CIDR: &mockPrivateSubnet3CIDR,
+						},
+					},
+				},
+			},
+		},
 		"succeed on empty config": {},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedErr == nil && tc.wantedErrorMsgPrefix == "" {
 				require.NoError(t, gotErr)
 			}
@@ -497,7 +671,7 @@ func TestEnvironmentVPCConfig_Validate(t *testing.T) {
 	}
 }
 
-func TestSubnetsConfiguration_Validate(t *testing.T) {
+func TestSubnetsConfiguration_validate(t *testing.T) {
 	var (
 		mockPublicSubnet1CIDR  = IPNet("10.0.0.0/24")
 		mockPrivateSubnet1CIDR = IPNet("10.0.3.0/24")
@@ -545,7 +719,7 @@ func TestSubnetsConfiguration_Validate(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedErrorMsgPrefix != "" {
 				require.Error(t, gotErr)
 				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
@@ -556,7 +730,61 @@ func TestSubnetsConfiguration_Validate(t *testing.T) {
 	}
 }
 
-func TestSubnetConfiguration_Validate(t *testing.T) {
+func TestCDNConfiguration_validate(t *testing.T) {
+	testCases := map[string]struct {
+		in                   environmentCDNConfig
+		wantedError          error
+		wantedErrorMsgPrefix string
+	}{
+		"valid if empty": {
+			in: environmentCDNConfig{},
+		},
+		"valid if bool specified": {
+			in: environmentCDNConfig{
+				Enabled: aws.Bool(false),
+			},
+		},
+		"valid if advanced config configured correctly": {
+			in: environmentCDNConfig{
+				Config: advancedCDNConfig{
+					Certificate: aws.String("arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"),
+				},
+			},
+		},
+		"error if certificate invalid": {
+			in: environmentCDNConfig{
+				Config: advancedCDNConfig{
+					Certificate: aws.String("arn:aws:weird-little-arn"),
+				},
+			},
+			wantedErrorMsgPrefix: "parse cdn certificate:",
+		},
+		"error if certificate in invalid region": {
+			in: environmentCDNConfig{
+				Config: advancedCDNConfig{
+					Certificate: aws.String("arn:aws:acm:us-west-2:1111111:certificate/look-like-a-good-arn"),
+				},
+			},
+			wantedError: errors.New("cdn certificate must be in region us-east-1"),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			gotErr := tc.in.validate()
+			if tc.wantedErrorMsgPrefix != "" {
+				require.Error(t, gotErr)
+				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
+			} else if tc.wantedError != nil {
+				require.Error(t, gotErr)
+				require.EqualError(t, tc.wantedError, gotErr.Error())
+			} else {
+				require.NoError(t, gotErr)
+			}
+		})
+	}
+}
+
+func TestSubnetConfiguration_validate(t *testing.T) {
 	mockCIDR := IPNet("10.0.0.0/24")
 	testCases := map[string]struct {
 		in          subnetConfiguration
@@ -608,7 +836,7 @@ func TestSubnetConfiguration_Validate(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedError != nil {
 				require.Error(t, gotErr)
 				require.EqualError(t, tc.wantedError, gotErr.Error())
@@ -619,21 +847,22 @@ func TestSubnetConfiguration_Validate(t *testing.T) {
 	}
 }
 
-func TestEnvironmentHTTPConfig_Validate(t *testing.T) {
+func TestEnvironmentHTTPConfig_validate(t *testing.T) {
 	testCases := map[string]struct {
-		in                   environmentHTTPConfig
+		in                   EnvironmentHTTPConfig
 		wantedErrorMsgPrefix string
+		wantedError          error
 	}{
 		"malformed public certificate": {
-			in: environmentHTTPConfig{
-				Public: publicHTTPConfig{
+			in: EnvironmentHTTPConfig{
+				Public: PublicHTTPConfig{
 					Certificates: []string{"arn:aws:weird-little-arn"},
 				},
 			},
 			wantedErrorMsgPrefix: `parse "certificates[0]": `,
 		},
 		"malformed private certificate": {
-			in: environmentHTTPConfig{
+			in: EnvironmentHTTPConfig{
 				Private: privateHTTPConfig{
 					Certificates: []string{"arn:aws:weird-little-arn"},
 				},
@@ -641,26 +870,55 @@ func TestEnvironmentHTTPConfig_Validate(t *testing.T) {
 			wantedErrorMsgPrefix: `parse "certificates[0]": `,
 		},
 		"success with public cert": {
-			in: environmentHTTPConfig{
-				Public: publicHTTPConfig{
+			in: EnvironmentHTTPConfig{
+				Public: PublicHTTPConfig{
 					Certificates: []string{"arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"},
 				},
 			},
 		},
 		"success with private cert": {
-			in: environmentHTTPConfig{
+			in: EnvironmentHTTPConfig{
 				Private: privateHTTPConfig{
 					Certificates: []string{"arn:aws:acm:us-east-1:1111111:certificate/look-like-a-good-arn"},
 				},
 			},
 		},
+		"public http config with invalid security group ingress": {
+			in: EnvironmentHTTPConfig{
+				Public: PublicHTTPConfig{
+					SecurityGroupConfig: ALBSecurityGroupsConfig{
+						Ingress: Ingress{
+							VPCIngress: aws.Bool(true),
+						},
+					},
+				},
+			},
+			wantedError: fmt.Errorf(`validate "public": a public load balancer already allows vpc ingress`),
+		},
+		"private http config with invalid security group ingress": {
+			in: EnvironmentHTTPConfig{
+				Private: privateHTTPConfig{
+					SecurityGroupsConfig: securityGroupsConfig{
+						Ingress: Ingress{
+							RestrictiveIngress: RestrictiveIngress{
+								CDNIngress: aws.Bool(true),
+							},
+						},
+					},
+				},
+			},
+			wantedError: fmt.Errorf(`validate "private": an internal load balancer cannot have restrictive ingress fields`),
+		},
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			gotErr := tc.in.Validate()
+			gotErr := tc.in.validate()
 			if tc.wantedErrorMsgPrefix != "" {
 				require.Error(t, gotErr)
 				require.Contains(t, gotErr.Error(), tc.wantedErrorMsgPrefix)
+			} else if tc.wantedError != nil {
+				require.Error(t, gotErr)
+				require.EqualError(t, tc.wantedError, gotErr.Error())
 			} else {
 				require.NoError(t, gotErr)
 			}
