@@ -24,6 +24,7 @@ var templateFS embed.FS
 // File names under "templates/".
 const (
 	DNSCertValidatorFileName            = "dns-cert-validator"
+	CertReplicatorFileName              = "cert-replicator"
 	DNSDelegationFileName               = "dns-delegation"
 	CustomDomainFileName                = "custom-domain"
 	AppRunnerCustomDomainLambdaFileName = "custom-domain-app-runner"
@@ -39,16 +40,10 @@ const (
 var (
 	envCustomResourceFiles = []string{
 		DNSCertValidatorFileName,
+		CertReplicatorFileName,
 		DNSDelegationFileName,
 		CustomDomainFileName,
 	}
-	rdWkldCustomResourceFiles = []string{
-		AppRunnerCustomDomainLambdaFileName,
-	}
-	nlbWkldCustomResourceFiles = []string{
-		NLBCertValidatorLambdaFileName,
-		NLBCustomDomainLambdaFileName,
-	}
 )
 
 // Reader is the interface that wraps the Read method.
@@ -130,16 +125,6 @@ func (t *Template) UploadEnvironmentCustomResources(upload s3.CompressAndUploadF
 	return t.uploadCustomResources(upload, envCustomResourceFiles)
 }
 
-// UploadRequestDrivenWebServiceCustomResources uploads the request driven web service custom resource scripts.
-func (t *Template) UploadRequestDrivenWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error) {
-	return t.uploadCustomResources(upload, rdWkldCustomResourceFiles)
-}
-
-// UploadNetworkLoadBalancedWebServiceCustomResources uploads the network load-balanced web service custom resource scripts.
-func (t *Template) UploadNetworkLoadBalancedWebServiceCustomResources(upload s3.CompressAndUploadFunc) (map[string]string, error) {
-	return t.uploadCustomResources(upload, nlbWkldCustomResourceFiles)
-}
-
 func (t *Template) uploadCustomResources(upload s3.CompressAndUploadFunc, fileNames []string) (map[string]string, error) {
 	urls := make(map[string]string)
 	for _, name := range fileNames {
