@@ -23,6 +23,9 @@ import (
 )
 
 const (
+	svcWorkloadType = "service"
+	jobWorkloadType = "job"
+
 	every         = "@every %s"
 	rate          = "Rate"
 	fixedSchedule = "Fixed Schedule"
@@ -67,6 +70,7 @@ const (
 	envNameFinalMessage = "Environment:"
 	svcNameFinalMsg     = "Service name:"
 	jobNameFinalMsg     = "Job name:"
+	deployedJobFinalMsg = "Job:"
 	deployedSvcFinalMsg = "Service:"
 	taskFinalMsg        = "Task:"
 	workloadFinalMsg    = "Name:"
@@ -177,15 +181,13 @@ type ConfigSelector struct {
 // LocalWorkloadSelector is an application and environment selector, but can also choose a service from the workspace.
 type LocalWorkloadSelector struct {
 	*ConfigSelector
-	ws      workspaceRetriever
-	appName string
+	ws workspaceRetriever
 }
 
 // LocalEnvironmentSelector is an application and environment selector, but can also choose an environment from the workspace.
 type LocalEnvironmentSelector struct {
 	*AppEnvSelector
-	ws      workspaceRetriever
-	appName string
+	ws workspaceRetriever
 }
 
 // WorkspaceSelector selects from local workspace.
@@ -216,9 +218,9 @@ type AppPipelineSelector struct {
 type DeploySelector struct {
 	*ConfigSelector
 	deployStoreSvc deployedWorkloadsRetriever
-	svc            string
+	name           string
 	env            string
-	filters        []DeployedServiceFilter
+	filters        []DeployedWorkloadFilter
 }
 
 // CFTaskSelector is a selector based on CF methods to get deployed one off tasks.
@@ -292,6 +294,15 @@ func NewLocalWorkloadSelector(prompt prompter, store configLister, ws workspaceR
 	}
 }
 
+// NewLocalEnvironmentSelector returns a new selector that chooses applications from the config store, but an environment
+// from the local workspace.
+func NewLocalEnvironmentSelector(prompt prompter, store configLister, ws workspaceRetriever) *LocalEnvironmentSelector {
+	return &LocalEnvironmentSelector{
+		AppEnvSelector: NewAppEnvSelector(prompt, store),
+		ws:             ws,
+	}
+}
+
 // NewWorkspaceSelector returns a new selector that prompts for local information.
 func NewWorkspaceSelector(prompt prompter, ws workspaceRetriever) *WorkspaceSelector {
 	return &WorkspaceSelector{
@@ -426,37 +437,37 @@ func (s *TaskSelector) RunningTask(msg, help string, opts ...TaskOpts) (*awsecs.
 }
 
 // GetDeployedServiceOpts sets up optional parameters for GetDeployedServiceOpts function.
-type GetDeployedServiceOpts func(*DeploySelector)
+type GetDeployedWorkloadOpts func(*DeploySelector)
 
-// DeployedServiceFilter determines if a service should be included in the results.
-type DeployedServiceFilter func(*DeployedService) (bool, error)
+// DeployedWorkloadFilter determines if a service or job should be included in the results.
+type DeployedWorkloadFilter func(*DeployedWorkload) (bool, error)
 
-// WithSvc sets up the svc name for DeploySelector.
-func WithSvc(svc string) GetDeployedServiceOpts {
+// WithName sets up the wkld name for DeploySelector.
+func WithName(name string) GetDeployedWorkloadOpts {
 	return func(in *DeploySelector) {
-		in.svc = svc
+		in.name = name
 	}
 }
 
 // WithEnv sets up the env name for DeploySelector.
-func WithEnv(env string) GetDeployedServiceOpts {
+func WithEnv(env string) GetDeployedWorkloadOpts {
 	return func(in *DeploySelector) {
 		in.env = env
 	}
 }
 
-// WithFilter sets up filters for DeploySelector
-func WithFilter(filter DeployedServiceFilter) GetDeployedServiceOpts {
+// WithWkldFilter sets up filters for DeploySelector
+func WithWkldFilter(filter DeployedWorkloadFilter) GetDeployedWorkloadOpts {
 	return func(in *DeploySelector) {
 		in.filters = append(in.filters, filter)
 	}
 }
 
 // WithServiceTypesFilter sets up a ServiceType filter for DeploySelector
-func WithServiceTypesFilter(svcTypes []string) GetDeployedServiceOpts {
-	return WithFilter(func(svc *DeployedService) (bool, error) {
+func WithServiceTypesFilter(svcTypes []string) GetDeployedWorkloadOpts {
+	return WithWkldFilter(func(svc *DeployedWorkload) (bool, error) {
 		for _, svcType := range svcTypes {
-			if svc.SvcType == svcType {
+			if svc.Type == svcType {
 				return true, nil
 			}
 		}
@@ -464,15 +475,39 @@ func WithServiceTypesFilter(svcTypes []string) GetDeployedServiceOpts {
 	})
 }
 
-// DeployedService contains the service name and environment name of the deployed service.
+// DeployedWorkload contains the name and environment name of the deployed workload.
+type DeployedWorkload struct {
+	Name string
+	Env  string
+	Type string
+}
+
+// String returns a string representation of the workload's name and environment.
+func (w *DeployedWorkload) String() string {
+	return fmt.Sprintf("%s (%s)", w.Name, w.Env)
+}
+
+// DeployedJob contains the name and environment of the deployed job.
+type DeployedJob struct {
+	Name string
+	Env  string
+}
+
+// String returns a string representation of the job's name and environment.
+func (j *DeployedJob) String() string {
+	return fmt.Sprintf("%s (%s)", j.Name, j.Env)
+}
+
+// DeployedService contains the name and environment of the deployed service.
 type DeployedService struct {
-	Svc     string
+	Name    string
 	Env     string
 	SvcType string
 }
 
+// String returns a string representation of the service's name and environment.
 func (s *DeployedService) String() string {
-	return fmt.Sprintf("%s (%s)", s.Svc, s.Env)
+	return fmt.Sprintf("%s (%s)", s.Name, s.Env)
 }
 
 // Task has the user select a task. Callers can provide an environment, an app, or a "use default cluster" option
@@ -525,24 +560,65 @@ func (s *CFTaskSelector) Task(msg, help string, opts ...GetDeployedTaskOpts) (st
 	return choice, nil
 }
 
+// DeployedJob has the user select a deployed job. Callers can provide either a particular environment,
+// a particular job to filter on, or both.
+func (s *DeploySelector) DeployedJob(msg, help string, app string, opts ...GetDeployedWorkloadOpts) (*DeployedJob, error) {
+	j, err := s.deployedWorkload(jobWorkloadType, msg, help, app, opts...)
+	if err != nil {
+		return nil, err
+	}
+	return &DeployedJob{
+		Name: j.Name,
+		Env:  j.Env,
+	}, nil
+}
+
 // DeployedService has the user select a deployed service. Callers can provide either a particular environment,
 // a particular service to filter on, or both.
-func (s *DeploySelector) DeployedService(msg, help string, app string, opts ...GetDeployedServiceOpts) (*DeployedService, error) {
+func (s *DeploySelector) DeployedService(msg, help string, app string, opts ...GetDeployedWorkloadOpts) (*DeployedService, error) {
+	svc, err := s.deployedWorkload(svcWorkloadType, msg, help, app, opts...)
+	if err != nil {
+		return nil, err
+	}
+	return &DeployedService{
+		Name:    svc.Name,
+		Env:     svc.Env,
+		SvcType: svc.Type,
+	}, nil
+}
+
+func (s *DeploySelector) deployedWorkload(workloadType string, msg, help string, app string, opts ...GetDeployedWorkloadOpts) (*DeployedWorkload, error) {
 	for _, opt := range opts {
 		opt(s)
 	}
+
+	var isWorkloadDeployed func(string, string, string) (bool, error)
+	var listDeployedWorkloads func(string, string) ([]string, error)
+	var finalMessage string
+	switch workloadType {
+	case svcWorkloadType:
+		isWorkloadDeployed = s.deployStoreSvc.IsServiceDeployed
+		listDeployedWorkloads = s.deployStoreSvc.ListDeployedServices
+		finalMessage = deployedSvcFinalMsg
+	case jobWorkloadType:
+		isWorkloadDeployed = s.deployStoreSvc.IsJobDeployed
+		listDeployedWorkloads = s.deployStoreSvc.ListDeployedJobs
+		finalMessage = deployedJobFinalMsg
+	default:
+		return nil, fmt.Errorf("unrecognized workload type %s", workloadType)
+	}
+
 	var err error
 	var envNames []string
-	svcTypes := map[string]string{}
-
-	// ServiceType is only utilized by the filtering functionality. No need to retrieve types if filters are not being applied
+	wkldTypes := map[string]string{}
+	// Type is only utilized by the filtering functionality. No need to retrieve types if filters are not being applied
 	if len(s.filters) > 0 {
-		services, err := s.workloadLister.ListServices(app)
+		workloads, err := s.workloadLister.ListWorkloads(app)
 		if err != nil {
-			return nil, fmt.Errorf("list services: %w", err)
+			return nil, fmt.Errorf("list %ss: %w", workloadType, err)
 		}
-		for _, svc := range services {
-			svcTypes[svc.Name] = svc.Type
+		for _, wkld := range workloads {
+			wkldTypes[wkld.Name] = wkld.Type
 		}
 	}
 
@@ -554,88 +630,88 @@ func (s *DeploySelector) DeployedService(msg, help string, app string, opts ...G
 			return nil, fmt.Errorf("list environments: %w", err)
 		}
 	}
-	svcEnvs := []*DeployedService{}
+	wkldEnvs := []*DeployedWorkload{}
 	for _, envName := range envNames {
-		var svcNames []string
-		if s.svc != "" {
-			deployed, err := s.deployStoreSvc.IsServiceDeployed(app, envName, s.svc)
+		var wkldNames []string
+		if s.name != "" {
+			deployed, err := isWorkloadDeployed(app, envName, s.name)
 			if err != nil {
-				return nil, fmt.Errorf("check if service %s is deployed in environment %s: %w", s.svc, envName, err)
+				return nil, fmt.Errorf("check if %s %s is deployed in environment %s: %w", workloadType, s.name, envName, err)
 			}
 			if !deployed {
 				continue
 			}
-			svcNames = append(svcNames, s.svc)
+			wkldNames = append(wkldNames, s.name)
 		} else {
-			svcNames, err = s.deployStoreSvc.ListDeployedServices(app, envName)
+			wkldNames, err = listDeployedWorkloads(app, envName)
 			if err != nil {
-				return nil, fmt.Errorf("list deployed service for environment %s: %w", envName, err)
+				return nil, fmt.Errorf("list deployed %ss for environment %s: %w", workloadType, envName, err)
 			}
 		}
-		for _, svcName := range svcNames {
-			svcEnv := &DeployedService{
-				Svc:     svcName,
-				Env:     envName,
-				SvcType: svcTypes[svcName],
+		for _, wkldName := range wkldNames {
+			wkldEnv := &DeployedWorkload{
+				Name: wkldName,
+				Env:  envName,
+				Type: wkldTypes[wkldName],
 			}
-			svcEnvs = append(svcEnvs, svcEnv)
+			wkldEnvs = append(wkldEnvs, wkldEnv)
 		}
 	}
-	if len(svcEnvs) == 0 {
-		return nil, fmt.Errorf("no deployed services found in application %s", color.HighlightUserInput(app))
+	if len(wkldEnvs) == 0 {
+		return nil, fmt.Errorf("no deployed %ss found in application %s", workloadType, color.HighlightUserInput(app))
 	}
 
-	if svcEnvs, err = s.filterServices(svcEnvs); err != nil {
+	if wkldEnvs, err = s.filterWorkloads(wkldEnvs); err != nil {
 		return nil, err
 	}
 
-	if len(svcEnvs) == 0 {
-		return nil, fmt.Errorf("no matching deployed services found in application %s", color.HighlightUserInput(app))
+	if len(wkldEnvs) == 0 {
+		return nil, fmt.Errorf("no matching deployed %ss found in application %s", workloadType, color.HighlightUserInput(app))
 	}
-	// return if only one deployed service found
-	var deployedSvc *DeployedService
-	if len(svcEnvs) == 1 {
-		deployedSvc = svcEnvs[0]
-		if s.svc == "" && s.env == "" {
-			log.Infof("Found only one deployed service %s in environment %s\n", color.HighlightUserInput(deployedSvc.Svc), color.HighlightUserInput(deployedSvc.Env))
+	// return if only one deployed workload found
+	var deployedWkld *DeployedWorkload
+	if len(wkldEnvs) == 1 {
+		deployedWkld = wkldEnvs[0]
+		if s.name == "" && s.env == "" {
+			log.Infof("Found only one deployed %s %s in environment %s\n", workloadType, color.HighlightUserInput(deployedWkld.Name), color.HighlightUserInput(deployedWkld.Env))
 		}
-		if (s.svc != "") != (s.env != "") {
-			log.Infof("Service %s found in environment %s\n", color.HighlightUserInput(deployedSvc.Svc), color.HighlightUserInput(deployedSvc.Env))
+		if (s.name != "") != (s.env != "") {
+			log.Infof("%s %s found in environment %s\n", strings.ToTitle(workloadType), color.HighlightUserInput(deployedWkld.Name), color.HighlightUserInput(deployedWkld.Env))
 		}
-		return deployedSvc, nil
+		return deployedWkld, nil
 	}
 
-	svcEnvNames := make([]string, len(svcEnvs))
-	svcEnvNameMap := map[string]*DeployedService{}
-	for i, svc := range svcEnvs {
-		svcEnvNames[i] = svc.String()
-		svcEnvNameMap[svcEnvNames[i]] = svc
+	wkldEnvNames := make([]string, len(wkldEnvs))
+	wkldEnvNameMap := map[string]*DeployedWorkload{}
+	for i, svc := range wkldEnvs {
+		wkldEnvNames[i] = svc.String()
+		wkldEnvNameMap[wkldEnvNames[i]] = svc
 	}
 
-	svcEnvName, err := s.prompt.SelectOne(
+	wkldEnvName, err := s.prompt.SelectOne(
 		msg,
 		help,
-		svcEnvNames,
-		prompt.WithFinalMessage(deployedSvcFinalMsg),
+		wkldEnvNames,
+		prompt.WithFinalMessage(finalMessage),
 	)
 	if err != nil {
-		return nil, fmt.Errorf("select deployed services for application %s: %w", app, err)
+		return nil, fmt.Errorf("select deployed %ss for application %s: %w", workloadType, app, err)
 	}
-	deployedSvc = svcEnvNameMap[svcEnvName]
+	deployedWkld = wkldEnvNameMap[wkldEnvName]
 
-	return deployedSvc, nil
+	return deployedWkld, nil
 }
 
-func (s *DeploySelector) filterServices(inServices []*DeployedService) ([]*DeployedService, error) {
-	outServices := inServices
+func (s *DeploySelector) filterWorkloads(inWorkloads []*DeployedWorkload) ([]*DeployedWorkload, error) {
+	outWorkloads := inWorkloads
 	for _, filter := range s.filters {
-		if result, err := filterDeployedServices(filter, outServices); err != nil {
+		if result, err := filterDeployedServices(filter, outWorkloads); err != nil {
 			return nil, err
 		} else {
-			outServices = result
+			outWorkloads = result
 		}
 	}
-	return outServices, nil
+	return outWorkloads, nil
 }
 
 // Service fetches all services in the workspace and then prompts the user to select one.
@@ -743,7 +819,7 @@ func (s *LocalEnvironmentSelector) LocalEnvironment(msg, help string) (wl string
 	}
 	filteredEnvNames := filterEnvsByName(envs, wsEnvNames)
 	if len(filteredEnvNames) == 0 {
-		return "", errors.New("no environments found")
+		return "", ErrLocalEnvsNotFound
 	}
 	if len(filteredEnvNames) == 1 {
 		log.Infof("Only found one environment, defaulting to: %s\n", color.HighlightUserInput(filteredEnvNames[0]))
@@ -1261,8 +1337,8 @@ func presetScheduleToDefinitionString(input string) string {
 	return fmt.Sprintf("@%s", strings.ToLower(input))
 }
 
-func filterDeployedServices(filter DeployedServiceFilter, inServices []*DeployedService) ([]*DeployedService, error) {
-	outServices := []*DeployedService{}
+func filterDeployedServices(filter DeployedWorkloadFilter, inServices []*DeployedWorkload) ([]*DeployedWorkload, error) {
+	outServices := []*DeployedWorkload{}
 	for _, svc := range inServices {
 		if include, err := filter(svc); err != nil {
 			return nil, err
